summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/Kolinewidthaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficeui/Kolinewidthaction.h')
-rw-r--r--lib/kofficeui/Kolinewidthaction.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/lib/kofficeui/Kolinewidthaction.h b/lib/kofficeui/Kolinewidthaction.h
index fe03de72..31991fb4 100644
--- a/lib/kofficeui/Kolinewidthaction.h
+++ b/lib/kofficeui/Kolinewidthaction.h
@@ -30,24 +30,25 @@
class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructs a KoLineWidthAction with a text and an icon.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoLineWidthAction(const QString& text, const QString& icon, QObject* parent = 0, const char* name = 0);
+ KoLineWidthAction(const TQString& text, const TQString& icon, TQObject* tqparent = 0, const char* name = 0);
/** Same as above, but it also connects a slot to the selectionChanged(int) signal.
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
* @param receiver The SLOT's parent.
* @param slot The SLOT to invoke when a lineWidthChanged(double) signal is emited.
* @param parent This action's parent.
* @param name An internal name for this action.
*/
- KoLineWidthAction(const QString& text, const QString& icon, const QObject* receiver,
- const char* slot, QObject* parent, const char* name = 0);
+ KoLineWidthAction(const TQString& text, const TQString& icon, const TQObject* receiver,
+ const char* slot, TQObject* tqparent, const char* name = 0);
~KoLineWidthAction();
/** Returns the currently selected line width */
@@ -87,8 +88,9 @@ class KOFFICEUI_EXPORT KoLineWidthAction : public KoSelectAction
class KoLineWidthChooser : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KoLineWidthChooser(QWidget* parent = 0, const char* name = 0);
+ KoLineWidthChooser(TQWidget* tqparent = 0, const char* name = 0);
~KoLineWidthChooser();
/** Returns the selected line width in points. */
@@ -30,24 +30,25 @@
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param parent This action's parent.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/
@@ -30,24 +30,25 @@
* @param text The text that will be displayed.
* @param icon The dynamically loaded icon that goes with this action.
- * @param receiver The SLOT's parent.
- * @param slot The SLOT to invoke when a lineWidthChanged(double) signal is emited.
- * @param parent This action's parent.
+ * @param receiver The SLOT's tqparent.
+ * @param slot The TQT_SLOT to invoke when a lineWidthChanged(double) signal is emited.
+ * @param tqparent This action's tqparent.
* @param name An internal name for this action.
*/